<!--********************************************************

    *FileName:      lineChart.vue
    *Description:   折线 图表

********************************************************-->

<template>
  <div :class="className" :style="{ width: width, height: height }"></div>
</template>

<script>
import * as echarts from 'echarts'
export default {
  name: 'LineChart',
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '350px'
    },
    autoResize: {
      type: Boolean,
      default: true
    },
    chartData: {
      type: Object,
      default: () => {}
    }
  },
  data() {
    return {
      chart: null
    }
  },
  watch: {
    chartData: {
      immediate: true,
      deep: true,
      handler(newVal, oldVal) {
        if (this.chart) {
          if (newVal) {
            this.setOptions(newVal)
          } else {
            this.setOptions(oldVal)
          }
        }
      }
    }
  },
  mounted() {
    this.initChart()
    if (this.chart) {
      window.addEventListener('resize', this.$_handleResizeChart)
    }
  },
  beforeDestroy() {
    if (!this.chart) {
      return false
    }
    this.chart.dispose()
    this.chart = null
    window.removeEventListener('resize', this.$_handleResizeChart)
  },
  methods: {
    $_handleResizeChart() {
      this.chart.resize()
    },
    setOptions({ time, Data, config } = {}) {
      const option = {
        color: config.color,
        legend: {
          top: '0',
          // itemGap: 50,
          data: config.name,
          textStyle: {
            color: config.textStyleColor || '#5470c6',
            fontSize: config.textStyleSize || 10
          },
          // 图例大小
          itemHeight: config.itemSize || 10
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'cross',
            label: {
              backgroundColor: '#6a7985'
            }
          }
        },
        grid: {
          containLabel: true,
          left: '5%',
          top: '15%',
          right: '5%',
          bottom: '2%'
        },
        xAxis: {
          type: 'category',
          // boundaryGap: false,
          axisLine: {
            show: true,
            lineStyle: {
              color: config.XlineColor,
              width: 1,
              type: 'solid'
            }
          },
          axisLabel: { textStyle: { color: '#808EA3', fontWeight: 'blod' },rotate: config.xRotate },
          axisTick: {
            show: false
          },
          data: time
        },
        yAxis: {
          type: 'value',
          axisLine: {
            show: false
          },
          axisTick: {
            show: false
          },
          splitLine: {
            lineStyle: {
              color: config.YlineColor,
              type: 'solid'
            }
          },
          axisLabel: { textStyle: { color: '#808EA3' } }
        },
        series: Data
      }
      this.chart.setOption(option)
    },
    initChart() {
      this.chart = echarts.init(this.$el)
      this.setOptions(this.chartData)
    }
  }
}
</script>
